
# THIS FILE IS GENERATED FROM PYART SETUP.PY
short_version = '1.1.1'
version = '1.1.1'
full_version = '1.1.1.dev+ff12924'
git_revision = 'ff129246b4e3d060c3af309cd4c44dfa01a5e267'
release = False

if not release:
    version = full_version
